#!/usr/bin/env python
# -*- coding: utf-8 -*-

from os import path
from setuptools import setup, find_packages

CURRENT_PATH = path.abspath(path.dirname(__file__))

with open(path.join(CURRENT_PATH, "README.md")) as file:
    readme = file.read()

with open(path.join(CURRENT_PATH, "HISTORY.md")) as file:
    history = file.read()


setup(
    name='pywerami',
    version='0.2.6',
    description="pywerami is a stand-alone program to make an countour/3D plot from a contour data file generated by the Perple_X program WERAMI.",
    long_description=readme + '\n\n' + history,
    long_description_content_type="text/markdown",
    author="Ondrej Lexa",
    author_email='lexa.ondrej@gmail.com',
    url='https://github.com/ondrolexa/pywerami',
    packages=find_packages(),
    package_data={'pywerami.images': ['*.png'],
                  'pywerami.samples': ['*.tab']},
    install_requires=["PyQt5", "numpy", "matplotlib", "scipy"],
    entry_points="""
    [console_scripts]
    pywerami=pywerami.mainapp:main
    """,
    license="MIT",
    zip_safe=False,
    keywords='pywerami',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Programming Language :: Python :: 3 :: Only',
        'Topic :: Scientific/Engineering',
        'Topic :: Utilities'
    ],
    project_urls={
        'Documentation': 'https://pywerami.readthedocs.io/',
        'Source Code': 'https://github.com/ondrolexa/pywerami/',
        'Bug Tracker': 'https://github.com/ondrolexa/pywerami/issues/',
    }
)
